# Release Workflow

1. Run `jupyter-notebook.ipynb` in JupyterLab
    1a. Check if README is correct.
    1b. Check version of installed packages.
    1b. Check the outputs.
    1c. Save `jupyter-notebook.ipynb`.

2. Check code metadata
    2a. Check `fibermat.__init__.py`
    2b. Check the year in copyright.
    2b. Verify the version: `fibermat.__version__`.

3. Check citation references in `README.md` and in `jupyter-notebook.ipynb`.

4. 
